<?php

namespace OrganizationsManagement\Service;

use Doctrine\ORM\EntityManager;
use OrganizationsManagement\Repository\Notice as NoticeRepository;
use OrganizationsManagement\Util\InstanceProvider;

class Notice
{
    /**
     * @var EntityManager
     */
    private $entityManager;
    /**
     * @var NoticeRepository
     */
    private $noticeRepository;

    /**
     * Notice constructor.
     * @param EntityManager $entityManager
     * @param NoticeRepository $NoticeRepository
     */
    public function __construct(EntityManager $entityManager, NoticeRepository $noticeRepository)
    {
        $this->entityManager = $entityManager;
        $this->noticeRepository = $noticeRepository;
    }

    public function findNotice()
    {
        return $this->noticeRepository->getNoticeRecords();
    }

    public function createNotice($data)
    {
        $environment = InstanceProvider::getLibEnvironment();

        $nrorg = $environment->getCurrentOrganizationId();
        $newCodeService = InstanceProvider::getService()->getNewCode();

        $id = $newCodeService->getCodeByTableName('INFORMATIVOECOMMERCE', $nrorg, 1, 10, true);

        $data['id'] = $id;
        $data['dateBegin'] = $data['dateBegin'] . ' 00:00:00';
        $data['dateEnd'] = $data['dateEnd'] . ' 00:00:00';
        $this->noticeRepository->insertNotice($data);
        $this->entityManager->flush();
    }

    public function deleteNotice($ids)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            foreach ($ids as $id) {
                $this->noticeRepository->deleteEcomOper($id);
                $this->noticeRepository->deleteNotice($id);
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }

    public function updateNotice($data)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            for ($i = 0; $i < sizeof($data); $i++) {
                $data[$i]['dateBegin'] = $data[$i]['dateBegin'] . ' 00:00:00';
                $data[$i]['dateEnd'] = $data[$i]['dateEnd'] . ' 00:00:00';
            }
            foreach ($data as $item) {
                $this->noticeRepository->updateNotice($item);
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }

    public function findTimeOutnotice()
    {
        return $this->noticeRepository->getTimeOutnotice();
    }

    public function saveTimeOutNotice($parametros)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        $environment = InstanceProvider::getLibEnvironment();
        $nrorg = $environment->getCurrentOrganizationId();
        $newCodeService = InstanceProvider::getService()->getNewCode();
        $cdoperador = $environment->getCdOperador();
        foreach ($parametros['ROW'] as $row) {
            $id = $row['ID'];
            $name = $row['DSNOME'];
            $qtDias = $row['QTDIAS'];
            $validate = $this->noticeRepository->validaRegistroIgual($connection, $id, $name);
            try {
                if ($id == 0) {
                    $id = $newCodeService->getCodeByTableName('INFORMATIVOECOMSILE', $nrorg, 1, 10, true);
                    if ($validate[0]["QTD"] > 0) {
                        throw new \Exception("EXISTE");
                    } else {
                        $this->noticeRepository->saveTimeOutNotice($connection, $id, $name, $qtDias, $cdoperador, $nrorg);
                    }
                } else {
                    if ($validate[0]["QTD"] > 0) {
                        throw new \Exception("EXISTE");
                    } else {
                        $this->noticeRepository->updateTimeOutNotice($connection, $id, $name, $qtDias, $cdoperador, $nrorg);
                    }
                }
                $connection->commit();
            } catch (\Exception $e) {
                $connection->rollback();
                throw $e;
            }
        }
    }

    public function deleteTimeOutNotice($parametros)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            foreach ($parametros as $row) {
                $id = $row['ID'];
                $this->noticeRepository->deleteTimeOutNotice($connection, $id);
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
    }
}
