import { DialogService, Form, LoadingService, Modal, ModalService, Select, TextInput } from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekTreeGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';
import { DialogServiceCustom } from '@/services/DialogServiceCustom';
import Messages from '@/services/Messages';

export class CadastroAssuntoController {
    public ModalCadAssuntoAdd!: Modal;

    public getText = '';

    public currentRow: any = {};

    public typeModal = '';

    public async addNewRow() {
        this.getText = 'Adicionar Assunto';
        this.ModalCadAssuntoAdd = await ModalService.createFromJson('/cadastroAssunto/modal/modalCadAssuntoAdd', true);
        this.ModalCadAssuntoAdd.show();
        this.typeModal = 'add';
    }

    public closeModalCadAssuntoAdd() {
        this.ModalCadAssuntoAdd.destroy();
    }

    public saveModalCadAssuntoAdd() {
        const modalCadAssuntoAddForm = Metadata.getInstance<Form>('modalCadAssuntoAddForm');
        const grid = Metadata.getInstance<TekTreeGrid>('tekTreeGridSubject');
        let paiID = null;
        let id = null;
        if (Metadata.getInstance<Select>('modalCadAssuntoAddForm-elementoSuperior').value !== null) {
            paiID = Metadata.getInstance<Select>('modalCadAssuntoAddForm-elementoSuperior').value;
        }
        if (Metadata.getInstance<TextInput>('modalCadAssuntoAddForm-ID').value !== null) {
            id = Metadata.getInstance<TextInput>('modalCadAssuntoAddForm-ID').value;
        }
        if (Utilities.validateForm(modalCadAssuntoAddForm)) {
            LoadingService.show();
            Http.post('/saveModalCadAssuntoAdd', {
                DSASSUNTO: Metadata.getInstance<TextInput>('modalCadAssuntoAddForm-DSASSUNTO').value,
                PAI_ID: paiID,
                ID: id,
            }).then(() => {
                this.closeModalCadAssuntoAdd();
                grid.datasource.setFilter({
                    PAI_ID: null,
                });
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public async beforeDeleteSubjects(params: any) {
		params.event.preventDefault();
        const buttonYes = [
            {
                name: Utilities.getNameDynamic('yes-'),
                component: 'ZdButton',
                label: 'Sim',
                events: {
                    click: () => {
                        DialogService.hide();
                        this.doDeleteSubjects(params);
                    },
                },
            },
        ];
        DialogServiceCustom.confirmMessage(Messages.DELETE_DEFAULT_TREE, buttonYes);
	}

	public async doDeleteSubjects(params: any) {
		LoadingService.show();
		try {
			await Http.post('/removeSubject', {
				data: params.component.selectedRows,
			});
            params.component.datasource.setFilter({
                PAI_ID: null,
            });
			params.component.selectedRows = [];
			params.component.datasource.get();
		} catch (e) {
			DialogServiceCustom.showErrorBackend(e);
		}
		LoadingService.hide();
	}

    public async rowClickFunction({ row }: any) {
        this.typeModal = 'edit';
        this.currentRow = row;
        this.ModalCadAssuntoAdd = await ModalService.createFromJson('/cadastroAssunto/modal/modalCadAssuntoAdd', true);
        this.ModalCadAssuntoAdd.show();
    }

    public async editRow() {
        if (this.typeModal === 'edit') {
            this.getText = 'Editar Assunto';
            Metadata.getInstance<TextInput>('modalCadAssuntoAddForm-DSASSUNTO').value = this.currentRow.DSASSUNTO;
            Metadata.getInstance<Select>('modalCadAssuntoAddForm-elementoSuperior').value = this.currentRow.PAI_ID;
            Metadata.getInstance<TextInput>('modalCadAssuntoAddForm-ID').value = this.currentRow.ID;
        }
    }

    public beforeReloadTekTreeGrid() {
        const grid = Metadata.getInstance<TekTreeGrid>('tekTreeGridSubject');
        grid.datasource.setFilter({
            PAI_ID: null,
        });
    }
}
